==> cactoos_0.49.orig.tar.gz: cactoos-0.49/src/test/java/org/cactoos/text/PaddedStartTest.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2020 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.text;

import org.junit.jupiter.api.Test;
import org.llorllale.cactoos.matchers.Assertion;
import org.llorllale.cactoos.matchers.TextHasString;

/**
 * Test case for {@link PaddedStart}.
 *
 * @since 0.1
 * @checkstyle JavadocMethodCheck (500 lines)
 */
final class PaddedStartTest {

    @Test
    void noPaddingIfOrigTextIsAsLongAsRequestedLength() {
        new Assertion<>(
            "Shouldn't pad the text",
            new PaddedStart(
                new TextOf("x"),
                1,
                '-'
            ),
            new TextHasString("x")
        ).affirm();
    }

    @Test
    void somePaddingIfOrigTextIsShorterThanRequestedLength() {
        new Assertion<>(
            "Should pad chars at start",
            new PaddedStart(
                new TextOf("x"),
                2,
                '-'
            ),
            new TextHasString("-x")
        ).affirm();
    }

    @Test
    void noPaddingIfRequestedLengthIsNegative()  {
        new Assertion<>(
            "Shouldn't consider negative min length",
            new PaddedStart(
                new TextOf("x"),
                -1,
                '-'
            ),
            new TextHasString("x")
        ).affirm();
    }
}

==> cactoos_0.54.0.orig.tar.gz: cactoos-0.54.0/src/test/java/org/cactoos/text/PaddedStartTest.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2017-2022 Yegor Bugayenko
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.cactoos.text;

import org.junit.jupiter.api.Test;
import org.llorllale.cactoos.matchers.Assertion;
import org.llorllale.cactoos.matchers.HasString;

/**
 * Test case for {@link PaddedStart}.
 *
 * @since 0.1
 * @checkstyle JavadocMethodCheck (500 lines)
 */
final class PaddedStartTest {

    @Test
    void noPaddingIfOrigTextIsAsLongAsRequestedLength() {
        new Assertion<>(
            "Shouldn't pad the text",
            new PaddedStart(
                new TextOf("x"),
                1,
                '-'
            ),
            new HasString("x")
        ).affirm();
    }

    @Test
    void somePaddingIfOrigTextIsShorterThanRequestedLength() {
        new Assertion<>(
            "Should pad chars at start",
            new PaddedStart(
                new TextOf("x"),
                2,
                '-'
            ),
            new HasString("-x")
        ).affirm();
    }

    @Test
    void noPaddingIfRequestedLengthIsNegative()  {
        new Assertion<>(
            "Shouldn't consider negative min length",
            new PaddedStart(
                new TextOf("x"),
                -1,
                '-'
            ),
            new HasString("x")
        ).affirm();
    }
}
